@@ -10,7 +10,7 @@ setup(
     author="Michael Droettboom",
     author_email="mdroettboom@mozilla.com",
     url="https://github.com/pyodide/pyodide",
-    packages=find_packages(
+    packages=[find_packages(
         where=".",
-    ),
+    )],
 )
